"""
Algo library

AutoML library for binary classification and regression tasks
Licence: MIT
"""


from . import automl
from . import features
from . import ml
from . import task


__all__ = [
    "automl",
    "features",
    "ml",
    "task"
]
